/** @jsx jsx */
import { useEffect, useState } from 'react';
import { css, jsx } from '@emotion/react';
import debounce from 'lodash/debounce';
import { CustomThemeButton } from '@atlaskit/button';
import CommentIcon from '@atlaskit/icon/glyph/comment';
import { layers } from '@atlaskit/theme/constants';
import { commentMessages as messages } from '../media';
const commentBadgeWrapper = css({
  position: 'absolute',
  // closest parent element with position relative is .resizer-hover-zone, which includes 10px padding
  right: '14px',
  top: '2px',
  borderRadius: '3px',
  zIndex: layers.card()
});
const getDefaultSize = node => {
  // width is the original width of image, not resized or currently rendered to user. Defaulting to medium for now
  return !node || node.attrs.width > 70 ? 'medium' : 'small';
};
export const CommentBadge = ({
  intl,
  mediaNode,
  mediaElement,
  onClick
}) => {
  const [badgeSize, setBadgeSize] = useState(getDefaultSize(mediaNode));
  const title = intl.formatMessage(messages.viewAndAddCommentsOnMedia);
  useEffect(() => {
    const observer = new ResizeObserver(debounce(entries => {
      const [entry] = entries;
      const {
        width,
        height
      } = entry.contentRect;
      setBadgeSize(width > 70 || height > 70 ? 'medium' : 'small');
    }));
    if (mediaElement) {
      observer.observe(mediaElement);
    }
    return () => {
      observer.disconnect();
    };
  }, [mediaElement]);
  const badgeDimensions = badgeSize === 'medium' ? '24px' : '16px';
  return jsx("div", {
    css: commentBadgeWrapper
  }, jsx(CustomThemeButton, {
    style: {
      height: badgeDimensions,
      width: badgeDimensions,
      background: "var(--ds-background-accent-yellow-subtler, #F8E6A0)",
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    },
    onClick: onClick,
    iconAfter: jsx(CommentIcon, {
      label: title,
      size: badgeSize
    })
  }));
};